@@ -23,8 +23,14 @@ timezone_handler () {
 
 	if [ "$utc" ]; then
 		ks_preseed base-config tzconfig/gmt boolean true
+		# requires clock-setup
+		ks_preseed d-i clock-setup/utc boolean true
 	else
 		ks_preseed base-config tzconfig/gmt boolean false
+		# requires clock-setup
+		ks_preseed d-i clock-setup/utc boolean false
 	fi
 	ks_preseed base-config tzconfig/preseed_zone string "$1"
+	# requires tzsetup
+	ks_preseed d-i time/zone string "$1"
 }
